==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PlikCsv.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PlikCsv extends GenericDPSObject {
    /**
     * PLIK_CSV.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PLIK_CSV.FORMAT_CSV_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long formatCsvId;

    /**
     * PLIK_CSV.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * PLIK_CSV.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * PLIK_CSV.MD5SUM
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String md5sum;

    /**
     * PLIK_CSV.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLIK_CSV.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PLIK_CSV.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PLIK_CSV.FORMAT_CSV_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getFormatCsvId() {
        return formatCsvId;
    }

    /**
     * PLIK_CSV.FORMAT_CSV_ID
     *
     * @param formatCsvId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setFormatCsvId(Long formatCsvId) {
        this.formatCsvId = formatCsvId;
    }

    /**
     * @return PLIK_CSV.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * PLIK_CSV.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PLIK_CSV.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * PLIK_CSV.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return PLIK_CSV.MD5SUM
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getMd5sum() {
        return md5sum;
    }

    /**
     * PLIK_CSV.MD5SUM
     *
     * @param md5sum
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMd5sum(String md5sum) {
        this.md5sum = md5sum == null ? null : md5sum.trim();
    }

    /**
     * @return PLIK_CSV.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * PLIK_CSV.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlikCsv other = (PlikCsv) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getFormatCsvId() == null ? other.getFormatCsvId() == null : this.getFormatCsvId().equals(other.getFormatCsvId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getMd5sum() == null ? other.getMd5sum() == null : this.getMd5sum().equals(other.getMd5sum()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getFormatCsvId() == null) ? 0 : getFormatCsvId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getMd5sum() == null) ? 0 : getMd5sum().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", formatCsvId=").append(formatCsvId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", md5sum=").append(md5sum);
        sb.append(", data=").append(data);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PlikCsv.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PlikCsv extends GenericDPSObject {
    /**
     * PLIK_CSV.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PLIK_CSV.FORMAT_CSV_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long formatCsvId;

    /**
     * PLIK_CSV.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * PLIK_CSV.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * PLIK_CSV.MD5SUM
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String md5sum;

    /**
     * PLIK_CSV.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLIK_CSV.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PLIK_CSV.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PLIK_CSV.FORMAT_CSV_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getFormatCsvId() {
        return formatCsvId;
    }

    /**
     * PLIK_CSV.FORMAT_CSV_ID
     *
     * @param formatCsvId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setFormatCsvId(Long formatCsvId) {
        this.formatCsvId = formatCsvId;
    }

    /**
     * @return PLIK_CSV.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * PLIK_CSV.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PLIK_CSV.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * PLIK_CSV.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return PLIK_CSV.MD5SUM
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getMd5sum() {
        return md5sum;
    }

    /**
     * PLIK_CSV.MD5SUM
     *
     * @param md5sum
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMd5sum(String md5sum) {
        this.md5sum = md5sum == null ? null : md5sum.trim();
    }

    /**
     * @return PLIK_CSV.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * PLIK_CSV.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlikCsv other = (PlikCsv) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getFormatCsvId() == null ? other.getFormatCsvId() == null : this.getFormatCsvId().equals(other.getFormatCsvId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getMd5sum() == null ? other.getMd5sum() == null : this.getMd5sum().equals(other.getMd5sum()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getFormatCsvId() == null) ? 0 : getFormatCsvId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getMd5sum() == null) ? 0 : getMd5sum().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", formatCsvId=").append(formatCsvId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", md5sum=").append(md5sum);
        sb.append(", data=").append(data);
        sb.append("]");
        return sb.toString();
    }
}
